scraper

package
v0.0.0-...-32120d4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 16, 2018 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ExtractGhazalAuthorAndName

func ExtractGhazalAuthorAndName(doc soup.Root, word *model.Word) *model.Word

ExtractGhazalAuthorAndName given a doc and a word, extracts either both the author and ghazal details or just the author info based on what the Rekhta page contains and adds these to the word object. It returns a reference to the word.

func ExtractVerseAndTranslation

func ExtractVerseAndTranslation(doc soup.Root, number int) []string

ExtractVerseAndTranslation , given a Root document and the number of the verse to extract, returns a slice of the verse and it's translation

func ScrapeTodayWord

func ScrapeTodayWord(date time.Time) model.Word

Function that loads the word of the day page from rekhta.org for the current day and scrapes it for the appropriate information Rekhta URL in the format of https://rekhta.org/archives/YEAR-MONTH-DAY/wordofthedays/ Returns a Word Object

Types

This section is empty.

Jump to