Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ExtractGhazalAuthorAndName ¶
ExtractGhazalAuthorAndName given a doc and a word, extracts either both the author and ghazal details or just the author info based on what the Rekhta page contains and adds these to the word object. It returns a reference to the word.
func ExtractVerseAndTranslation ¶
ExtractVerseAndTranslation , given a Root document and the number of the verse to extract, returns a slice of the verse and it's translation
func ScrapeTodayWord ¶
Function that loads the word of the day page from rekhta.org for the current day and scrapes it for the appropriate information Rekhta URL in the format of https://rekhta.org/archives/YEAR-MONTH-DAY/wordofthedays/ Returns a Word Object
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.